@@ -85,6 +85,8 @@ def ema(ema_x, next_x, alpha=0.9):
 
 
 def smooth_ema(X, alpha=0.9):
+    if len(X) == 0:
+        return X
     res = []
     z = X[0]
     for x in X:
@@ -93,10 +95,12 @@ def smooth_ema(X, alpha=0.9):
     return np.array(res)
 
 
-def smooth_conv(y, box_pts, mode='valid'):
+def smooth_conv(X, box_pts, mode='valid'):
+    if len(X) == 0:
+        return X
     box = np.ones(box_pts) / box_pts
-    y_smooth = np.convolve(y, box, mode=mode)
-    return y_smooth
+    X_smooth = np.convolve(X, box, mode=mode)
+    return X_smooth
 
 
 def bchw_to_bhwc(x):
